
Credits
=======

Development Lead
----------------


* Ag Stephens ag.stephens@stfc.ac.uk

Co-Developers
-------------

* Eleanor Smith eleanor.smith@stfc.ac.uk `@ellesmith88 <https://github.com/ellesmith88>`_
* Carsten Ehbrecht ehbrecht@dkrz.de
* Trevor James Smith smith.trevorj@ouranos.ca `@Zeitsperre <https://github.com/Zeitsperre>`_

Contributors
------------

* Pascal Bourgault bourgault.pascal@ouranos.ca `@aulemahal <https://github.com/aulemahal>`_
* David Huard huard.david@ouranos.ca `@huard <https://github.com/huard>`_
* Martin Schupfner schupfner@dkrz.de `@sol1105 <https://github.com/sol1105>`_
